##### cryptomodel
Contains the model and data access methods  for cryptos and coinmarketcap  stores in mongo db

user_notification :  



###### to package 
https://packaging.python.org/tutorials/packaging-projects/


###### to use 
pip install -i https://test.pypi.org/simple/CryptoModel-athanikos==0.0.1




#### to deploy 
source bin/activate 
python3 -m pip install --upgrade build
rm -rf dist 
python3 -m build 









